@@ -1,7 +1,7 @@
 /*
    Kickshaw - A Menu Editor for Openbox
 
-   Copyright (c) 2010–2022        Marcus Schätzle
+   Copyright (c) 2010–2024        Marcus Schätzle
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -85,34 +85,25 @@ static gchar *compute_hypothetical_replacement (const gchar *value)
     const gchar *replace_entry_str = gtk_entry_get_text (GTK_ENTRY (ks.fr_entry_fields[REPLACE_ENTRY]));
     const gchar *with_entry_str = gtk_entry_get_text (GTK_ENTRY (ks.fr_entry_fields[WITH_ENTRY]));
 
+    g_autofree gchar *replace_entry_str_escaped = (gtk_toggle_button_get_active 
+                                                      (GTK_TOGGLE_BUTTON (ks.fr_special_options[REGULAR_EXPRESSION]))) ? 
+                                                  NULL : g_regex_escape_string (replace_entry_str, -1);
+    const gboolean whole_word = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ks.fr_special_options[WHOLE_WORD]));
+    g_autofree gchar *final_replace_str = g_strconcat ((whole_word) ? "\\b(" : "", 
+                                                       (replace_entry_str_escaped) ? replace_entry_str_escaped : replace_entry_str, 
+                                                       (whole_word) ? ")\\b" : "", 
+                                                       NULL);
     gchar *new_value = NULL; // Default, no match found.
 
-    const gboolean whole_word = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ks.fr_special_options[WHOLE_WORD]));
-    g_autofree gchar *final_replace_str = g_strconcat ((whole_word) ? "\\b(" : "", replace_entry_str, (whole_word) ? ")\\b" : "", NULL);
+    if (g_regex_match_simple (final_replace_str, value, 
+                              (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ks.fr_special_options[MATCH_CASE]))) ? 
+                              0 : G_REGEX_CASELESS, 
+                              G_REGEX_MATCH_NOTEMPTY)) {
+        g_autoptr(GRegex) regex = g_regex_new (final_replace_str, 
+                                               (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ks.fr_special_options[MATCH_CASE]))) ? 
+                                               0 : G_REGEX_CASELESS, G_REGEX_MATCH_NOTEMPTY, NULL);
 
-    if (regex_match_simple (final_replace_str, value, get_compile_options (FIND_AND_REPLACE), PCRE2_NOTEMPTY)) {
-        gint error_number;
-        PCRE2_SIZE error_offset;
-
-		gint return_code;
-
-        PCRE2_SIZE new_value_size = strlen (value) + 1;
-        new_value = g_malloc (sizeof (gchar) * new_value_size);
-
-        // error_number and error_offset are needed, even if they are not used.
-        g_autoptr(pcre2_code) compiled_pattern = pcre2_compile ((PCRE2_SPTR8) final_replace_str, PCRE2_ZERO_TERMINATED, 
-                                                                (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ks.fr_special_options[MATCH_CASE]))) ? 
-                                                                PCRE2_UTF : PCRE2_UTF | PCRE2_CASELESS, &error_number, &error_offset, NULL);
-
-        do {
-            return_code = pcre2_substitute (compiled_pattern, (PCRE2_SPTR) value, PCRE2_ZERO_TERMINATED, 0, 
-                                            PCRE2_NOTEMPTY | PCRE2_SUBSTITUTE_GLOBAL | PCRE2_SUBSTITUTE_OVERFLOW_LENGTH, NULL, NULL, 
-                                            (PCRE2_SPTR) with_entry_str, PCRE2_ZERO_TERMINATED, (PCRE2_UCHAR *) new_value, &new_value_size);
-
-            if (return_code == PCRE2_ERROR_NOMEMORY) {
-                new_value = g_realloc (new_value, sizeof (gchar) * new_value_size);
-            }
-        } while (return_code < 1);
+        new_value = g_regex_replace (regex, value, -1, 0, with_entry_str, 0, NULL);
     }
 
     return new_value;
@@ -153,12 +144,12 @@ static gboolean validity_check (              GtkTreeModel *model,
         g_autofree gchar *value, *new_value = NULL;
 
         gtk_tree_model_get (model, iter, TS_VALUE, &value, -1);
-        if ((new_value = compute_hypothetical_replacement (value)) && 
-            !streq_any (new_value, "yes", "no", NULL)) {
-            g_autofree gchar *err_msg = g_strdup_printf ("An <b>\"enabled\"</b> option can't have a value other than "
-                                                         "<b>\"yes\"</b> or <b>\"no\"</b> and thus a replacement of "
-                                                         "\"%s\" with \"%s\" won't be done.\n\n"
-                                                         "<b><span foreground='%s'>Find and replace action not executed.</span></b>", 
+        if (G_UNLIKELY ((new_value = compute_hypothetical_replacement (value)) && 
+                        !streq_any (new_value, "yes", "no", NULL))) {
+            g_autofree gchar *err_msg = g_strdup_printf (_("An <b>\"enabled\"</b> option can't have a value other than "
+                                                           "<b>\"yes\"</b> or <b>\"no\"</b> and thus a replacement of "
+                                                           "\"%s\" with \"%s\" won't be done.\n\n"
+                                                           "<b><span foreground='%s'>Find and replace action not executed.</span></b>"), 
                                                          value, with_entry_str, ks.red_hue);
             show_errmsg (err_msg);
 
@@ -166,7 +157,7 @@ static gboolean validity_check (              GtkTreeModel *model,
         }
 
         if (!(*no_invalid_replacements)) {
-            return TRUE; // Stop iterating through the tree store.
+            return STOP_ITERATING;
         }
     }
 
@@ -182,12 +173,12 @@ static gboolean validity_check (              GtkTreeModel *model,
             GSList *menu_ids_loop;
 
             FOREACH_IN_LIST (ks.menu_ids, menu_ids_loop) {
-                if (STREQ (menu_ids_loop->data, new_menu_id_txt) && !STREQ (new_menu_id_txt, menu_id_txt)) {
-                    g_autofree gchar *err_msg = g_strdup_printf ("The menu ID <b>\"%s\"</b> won't be replaced with <b>\"%s\"</b>, "
-                                                                 "because this would create a double menu ID.\n\n"
-                                                                 "<b><span foreground='%s'>"
-                                                                 "Find and replace action not executed."
-                                                                 "</span></b>", 
+                if (G_UNLIKELY (STREQ (menu_ids_loop->data, new_menu_id_txt) && !STREQ (new_menu_id_txt, menu_id_txt))) {
+                    g_autofree gchar *err_msg = g_strdup_printf (_("The menu ID <b>\"%1$s\"</b> won't be replaced with <b>\"%2$s\"</b>, "
+                                                                   "because this would create a double menu ID.\n\n"
+                                                                   "<b><span foreground='%3$s'>"
+                                                                   "Find and replace action not executed."
+                                                                   "</span></b>"), 
                                                                  menu_id_txt, new_menu_id_txt, ks.red_hue);
 
                     show_errmsg (err_msg);
@@ -217,14 +208,14 @@ static gboolean validity_check (              GtkTreeModel *model,
                             // x1F (dec. 31) = unit separator
                             g_auto(GStrv) menu_IDs_before_and_after_pair2 = g_strsplit (menu_ids_loop->next->data, "\x1F", -1);
 
-                            if (STREQ (menu_IDs_before_and_after_pair1[0], menu_IDs_before_and_after_pair2[0])) {
-                                g_autofree gchar *err_msg = g_strdup_printf ("A find and replace with these values "
-                                                                             "would replace both menu IDs "
-                                                                             "<b>\"%s\"</b> and <b>\"%s\"</b> with <b>\"%s\"</b>, "
-                                                                             "thus creating a double menu ID.\n\n"
-                                                                             "<b><span foreground='%s'>"
-                                                                             "Find and replace action not executed."
-                                                                             "</span></b>", 
+                            if (G_UNLIKELY (STREQ (menu_IDs_before_and_after_pair1[0], menu_IDs_before_and_after_pair2[0]))) {
+                                g_autofree gchar *err_msg = g_strdup_printf (_("A find and replace with these values "
+                                                                               "would replace both menu IDs "
+                                                                               "<b>\"%1$s\"</b> and <b>\"%2$s\"</b> with <b>\"%3$s\"</b>, "
+                                                                               "thus creating a double menu ID.\n\n"
+                                                                               "<b><span foreground='%4$s'>"
+                                                                               "Find and replace action not executed."
+                                                                               "</span></b>"), 
                                                                              menu_IDs_before_and_after_pair1[1], 
                                                                              menu_IDs_before_and_after_pair2[1], 
                                                                              menu_IDs_before_and_after_pair1[0], 
@@ -240,30 +231,46 @@ static gboolean validity_check (              GtkTreeModel *model,
         }
 
         if (!(*no_invalid_replacements)) {
-            return TRUE; // Stop iterating through the tree store.
+            return STOP_ITERATING;
         }
     }
 
     if (!(*with_entry_str)) {
 
-        // Make sure that there will be no empty (pipe) menu labels after a find and replace.
+        // Make sure that there will be no empty (pipe) menu and item labels after a find and replace.
 
-        if (streq_any (type_txt, "menu", "pipe menu", NULL) && 
+        if (streq_any (type_txt, "menu", "pipe menu", "item", NULL) && 
             gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ks.fr_in_columns[COL_MENU_ELEMENT]))) {
             g_autofree gchar *new_menu_element_txt = compute_hypothetical_replacement (menu_element_txt);
 
-            if (STREQ (new_menu_element_txt, "")) {
-                g_autofree gchar *menu_id_txt;
+            if (G_UNLIKELY (STREQ (new_menu_element_txt, ""))) {
+                g_autofree gchar *substr;
 
-                gtk_tree_model_get (model, iter, TS_MENU_ID, &menu_id_txt, -1);
+                if (streq_any (type_txt, "menu", "pipe menu", NULL)) {
+                    g_autofree gchar *menu_id_txt;
+
+                    gtk_tree_model_get (model, iter, TS_MENU_ID, &menu_id_txt, -1); 
+
+                    if (STREQ (type_txt, "menu")) {                    
+                        substr = g_strdup_printf (_("The menu <b>\"%1$s\"</b> with the menu ID <b>\"%2$s\"</b> won't "
+                                                   "receive an empty label, because this would render the menu invisible."), 
+                                                    menu_element_txt, menu_id_txt);
+                    }
+                    else { // pipe menu
+                        substr = g_strdup_printf (_("The pipe menu <b>\"%1$s\"</b> with the menu ID <b>\"%2$s\"</b> won't "
+                                                    "receive an empty label, because this would render the pipe menu invisible."), 
+                                                    menu_element_txt, menu_id_txt);
+                    }
+                }
+                else { // item
+                    substr = g_strdup_printf (_("The item with the label <b>\"%s\"</b> won't "
+                                                "receive an empty label, because this would render the item invisible."), 
+                                                menu_element_txt);
+                }
+
+                g_autofree gchar *err_msg = g_strdup_printf ("%s\n\n<b><span foreground='%s'>%s</span></b>", 
+                                                             substr, ks.red_hue, _("Find and replace action not executed."));
 
-                g_autofree gchar *err_msg = g_strdup_printf ("The %s menu <b>\"%s\"</b> with the menu ID <b>\"%s\"</b> won't "
-                                                             "receive an empty label, because this would render the menu invisible.\n\n"
-                                                             "<b><span foreground='%s'>"
-                                                             "Find and replace action not executed."
-                                                             "</span></b>", 
-                                                             (STREQ (type_txt, "menu")) ? "" : "pipe", 
-                                                             menu_element_txt, menu_id_txt, ks.red_hue);
                 show_errmsg (err_msg);
 
                 *no_invalid_replacements = FALSE;
@@ -280,17 +287,17 @@ static gboolean validity_check (              GtkTreeModel *model,
 
             g_autofree gchar *new_execute_txt = compute_hypothetical_replacement (execute_txt);
 
-            if (STREQ (new_execute_txt, "")) {
+            if (G_UNLIKELY (STREQ (new_execute_txt, ""))) {
                 g_autofree gchar *menu_id_txt;
 
                 gtk_tree_model_get (model, iter, TS_MENU_ID, &menu_id_txt, -1);
 
-                g_autofree gchar *err_msg = g_strdup_printf ("The execute instruction of the pipe menu <b>\"%s\"</b> "
-                                                             "with the menu ID <b>\"%s\"</b> won't be deleted, "
-                                                             "because this would render this pipe menu useless.\n\n"
-                                                             "<b><span foreground='%s'>"
-                                                             "Find and replace action not executed."
-                                                             "</span></b>", 
+                g_autofree gchar *err_msg = g_strdup_printf (_("The execute instruction of the pipe menu <b>\"%1$s\"</b> "
+                                                               "with the menu ID <b>\"%2$s\"</b> won't be deleted, "
+                                                               "because this would render this pipe menu useless.\n\n"
+                                                               "<b><span foreground='%3$s'>"
+                                                               "Find and replace action not executed."
+                                                               "</span></b>"), 
                                                              menu_element_txt, menu_id_txt, ks.red_hue);
 
                 show_errmsg (err_msg);
@@ -341,7 +348,7 @@ static gboolean find_and_replace_iteration (              GtkTreeModel *model,
         if (!(*replace_entry_str)) {
             // The program allows to find empty fields and fill them with a value, provided they can also be entered manually.
             if (!NOT_NULL_AND_NOT_EMPTY (current_column_txt) && 
-                // The invalid types "action", "option block" and "option" have already been taken care of above.
+                // The invalid types "action", "option block", and "option" have already been taken care of above.
                 (columns_cnt == COL_MENU_ELEMENT || 
                  (columns_cnt == COL_VALUE && STREQ (type_txt, "option")) || 
                  (columns_cnt == COL_MENU_ID && STREQ (type_txt, "menu")) || 
@@ -349,7 +356,7 @@ static gboolean find_and_replace_iteration (              GtkTreeModel *model,
                 gtk_tree_store_set (ks.treestore, iter, columns_cnt + TREEVIEW_COLUMN_OFFSET, with_entry_str, -1);
 
                 /* It's simpler to overwrite the visibility status regardless of the previous status than to query the status first.
-                   Only the status of the types "menu", "pipe menu", "item" and "separator" is overwritten, since the other types 
+                   Only the status of the types "menu", "pipe menu", "item", and "separator" is overwritten, since the other types 
                    were already skipped above. */
                 if (columns_cnt == COL_MENU_ELEMENT) {
                     gtk_tree_store_set (ks.treestore, iter, TS_ELEMENT_VISIBILITY, "visible", -1);
@@ -376,60 +383,49 @@ static gboolean find_and_replace_iteration (              GtkTreeModel *model,
             continue;
         }
 
-        g_autofree gchar *final_replace_str = g_strconcat ((whole_word) ? "\\b(" : "", replace_entry_str, (whole_word) ? ")\\b" : "", NULL);
+        g_autofree gchar *replace_entry_str_escaped = (gtk_toggle_button_get_active 
+                                                          (GTK_TOGGLE_BUTTON (ks.fr_special_options[REGULAR_EXPRESSION]))) ? 
+                                                       NULL : g_regex_escape_string (replace_entry_str, -1);
+        g_autofree gchar *final_replace_str = g_strconcat ((whole_word) ? "\\b(" : "", 
+                                                           (replace_entry_str_escaped) ? replace_entry_str_escaped : replace_entry_str, 
+                                                           (whole_word) ? ")\\b" : "", 
+                                                           NULL);
 
-        gint error_number;
-        PCRE2_SIZE error_offset;
+        g_autoptr(GRegex) regex = g_regex_new (final_replace_str, 
+                                               (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ks.fr_special_options[MATCH_CASE]))) ? 
+                                               0 : G_REGEX_CASELESS, G_REGEX_MATCH_NOTEMPTY, NULL);
+        g_autoptr(GMatchInfo) match_info;
 
-        PCRE2_SIZE new_current_column_txt_size = strlen (current_column_txt) + 1;
-        g_autofree gchar *new_current_column_txt = g_malloc (sizeof (gchar) * new_current_column_txt_size);
-
-        // error_number and error_offset are needed, even if they are not used.
-        g_autoptr(pcre2_code) compiled_pattern = pcre2_compile ((PCRE2_SPTR) final_replace_str, PCRE2_ZERO_TERMINATED, 
-                                                                get_compile_options (FIND_AND_REPLACE), &error_number, &error_offset, NULL);
-                                                                
-        g_autoptr(pcre2_match_data) match_data = pcre2_match_data_create_from_pattern (compiled_pattern, NULL);
-
-        gint return_code = pcre2_match (compiled_pattern, (PCRE2_SPTR) current_column_txt, PCRE2_ZERO_TERMINATED, 
-                                        0, PCRE2_NOTEMPTY, match_data, NULL);
-
-        // No matches
-        if (return_code < 1) {
+        if (!g_regex_match (regex, current_column_txt, 0, &match_info)) {
             continue;
         }
 
-        do {
-            return_code = pcre2_substitute (compiled_pattern, (PCRE2_SPTR) current_column_txt, PCRE2_ZERO_TERMINATED, 0, 
-                                            PCRE2_NOTEMPTY | PCRE2_SUBSTITUTE_GLOBAL | PCRE2_SUBSTITUTE_OVERFLOW_LENGTH, NULL, NULL, 
-                                            (PCRE2_SPTR) with_entry_str, PCRE2_ZERO_TERMINATED, 
-                                            (PCRE2_UCHAR *) new_current_column_txt, &new_current_column_txt_size);
-
-            if (return_code == PCRE2_ERROR_NOMEMORY) {
-                new_current_column_txt = g_realloc (new_current_column_txt, sizeof (gchar) * new_current_column_txt_size);
-            }
-        } while (return_code < 1);
-
-        *replacements_done_cnt += return_code;
+        g_autofree gchar *new_column_txt = g_regex_replace (regex, current_column_txt, -1, 0, with_entry_str, 0, NULL);
 
         // The program won't store empty separator labels; a separator should be either with or without text.
         gtk_tree_store_set (ks.treestore, iter, columns_cnt + TREEVIEW_COLUMN_OFFSET, 
-                            !(!(*new_current_column_txt) && STREQ (type_txt, "separator")) ? new_current_column_txt : NULL, -1);
+                            !(!(*new_column_txt) && STREQ (type_txt, "separator")) ? new_column_txt : NULL, -1);
 
         if (columns_cnt == COL_MENU_ID) {
             remove_menu_id (current_column_txt);
-            ks.menu_ids = g_slist_prepend (ks.menu_ids, g_strdup (new_current_column_txt));
+            ks.menu_ids = g_slist_prepend (ks.menu_ids, g_strdup (new_column_txt));
+        }
+
+        while (g_match_info_matches (match_info)) {
+            ++(*replacements_done_cnt);
+            g_match_info_next (match_info, NULL);
         }
     }
 
-    return FALSE;
+    return CONTINUE_ITERATING;
 }
 
 /*
 
-    If by find and replace one or several labelless menus, items and/or separators have received a label, 
-    this means all menus, items and separators will have a label now.
+    If by find and replace one or several labelless menus, items, and/or separators have received a label, 
+    this means all menus, items, and separators will have a label now.
     Instead of checking if there are any menus/items/separators left for which the visibility would have 
-    to be set to "visible", for simplicity visibility is set to "visible" for all menus, items and separators.
+    to be set to "visible", for simplicity visibility is set to "visible" for all menus, items, and separators.
 
 */
 
@@ -446,7 +442,7 @@ static gboolean set_all_menus_items_and_seps_to_visible (              GtkTreeMo
         gtk_tree_store_set (ks.treestore, iter, TS_ELEMENT_VISIBILITY, "visible", -1);
     }
 
-    return FALSE;
+    return CONTINUE_ITERATING;
 }
 
 /*
@@ -498,7 +494,8 @@ static void find_and_replace_intialization (G_GNUC_UNUSED gpointer user_data)
 
     if (fr_data.no_invalid_replacements) {
         g_autofree gchar *replacements_done_label_txt;
-        const gchar *small_numbers_spelled_out[] = { "once", "twice", "three", "four", "five", "six", "seven", "eight", "nine" };
+        const gchar *small_numbers_spelled_out[] = { N_("once"), N_("twice"), N_("three times"), N_("four times"), N_("five times"), 
+                                                     N_("six times"), N_("seven times"), N_("eight times"), N_("nine times") };
 
         fr_data.replacements_done_cnt = 0; // Default
 
@@ -506,11 +503,9 @@ static void find_and_replace_intialization (G_GNUC_UNUSED gpointer user_data)
 
         replacements_done_label_txt = (fr_data.replacements_done_cnt) ? 
                                       ((fr_data.replacements_done_cnt < 10) ? 
-                                       g_strconcat ("Search key replaced ", 
-                                                    small_numbers_spelled_out[(fr_data.replacements_done_cnt) - 1], 
-                                                    (fr_data.replacements_done_cnt < 3) ? "." : " times.", NULL) :
-                                       g_strdup_printf ("Search key replaced %i times.", fr_data.replacements_done_cnt)) :
-                                       g_strdup ("Search key not found.");
+                                       g_strdup_printf (_("Search key replaced %s."), _(small_numbers_spelled_out[(fr_data.replacements_done_cnt) - 1])) : 
+                                       g_strdup_printf (ngettext ("Search key replaced %i times.", "Search key replaced %i times.", fr_data.replacements_done_cnt), fr_data.replacements_done_cnt)) : 
+                                       g_strdup (_("Search key not found."));
         gtk_label_set_text (GTK_LABEL (ks.fr_replacements_done_label), replacements_done_label_txt);
 
         if (fr_data.replacements_done_cnt) {
@@ -518,10 +513,10 @@ static void find_and_replace_intialization (G_GNUC_UNUSED gpointer user_data)
                 gtk_tree_model_foreach (ks.ts_model, (GtkTreeModelForeachFunc) set_all_menus_items_and_seps_to_visible, NULL);
             }
 
-            push_new_item_on_undo_stack (FALSE); // First update undo stack so ...
+            push_new_item_on_undo_stack (NOT_AFTER_SAVE); // First update undo stack so ...
             activate_change_done ();
-            row_selected ();                     /* ... the toolbar buttons and 
-                                                        application menu's undo/redo items get the correct sensitivity settings. */
+            row_selected ();                              /* ... the toolbar buttons and 
+                                                             application menu's undo/redo items get the correct sensitivity settings. */
         }
     }
 
@@ -537,17 +532,18 @@ static void find_and_replace_intialization (G_GNUC_UNUSED gpointer user_data)
 
 void show_find_and_replace_dialog (void)
 {
-    if (GTK_IS_WIDGET (ks.fr_dialog)) {
+    if (ks.fr_dialog) {
         gtk_window_present (GTK_WINDOW (ks.fr_dialog));
 
         return;
     }
 
     ks.fr_dialog = gtk_dialog_new_with_buttons (NULL, GTK_WINDOW (ks.window), GTK_DIALOG_DESTROY_WITH_PARENT, 
-                                                "_Replace", 1, "_Close", 2, NULL);
-    set_header_bar_for_dialog (ks.fr_dialog, "Find and Replace");
+                                                _("_Replace"), 1, _("_Close"), 2, NULL);
+    set_header_bar_for_dialog (ks.fr_dialog, _("Find and Replace"));
     gtk_widget_add_events (ks.fr_dialog, GDK_KEY_PRESS_MASK);
     g_signal_connect (G_OBJECT (ks.fr_dialog), "key-press-event", G_CALLBACK (close_window), "<ctrl>H");
+    g_signal_connect (G_OBJECT (ks.fr_dialog), "destroy", G_CALLBACK (gtk_widget_destroyed), &ks.fr_dialog);
 
     ks.fr_entry_fields[REPLACE_ENTRY] = gtk_entry_new ();
     ks.fr_entry_fields[WITH_ENTRY] = gtk_entry_new ();
@@ -559,9 +555,9 @@ void show_find_and_replace_dialog (void)
     GtkWidget *columns_grid = gtk_grid_new ();
     GtkWidget *special_options_grid = gtk_grid_new ();
     enum { FR_REPLACE_LABEL, FR_IN_LABEL, FR_WITH_LABEL, NUMBER_OF_FR_LABEL_FIELDS };
-    const gchar *fr_label_txts[] = { "<b>Replace: </b>", "<b>In:</b>", "<b>With:</b>" };
+    const gchar *fr_label_txts[] = { _("<b>Replace: </b>"), _("<b>In:</b>"), _("<b>With:</b>") };
     GtkWidget *fr_labels[NUMBER_OF_FR_LABEL_FIELDS] = { gtk_label_new (NULL), gtk_label_new (NULL), gtk_label_new (NULL) };
-    const gchar *special_options_txts[] = { "Match Case", "Regular Expression (PCRE)", "Whole Word" };
+    const gchar *special_options_txts[] = { _("Match Case"), _("Regular Expression (PCRE)"), _("Whole Word") };
 
     gint8 columns_cnt;
 
@@ -582,7 +578,7 @@ void show_find_and_replace_dialog (void)
             continue;
         }
 
-        ks.fr_in_columns[columns_cnt] = gtk_check_button_new_with_label (ks.column_header_txts[columns_cnt]);
+        ks.fr_in_columns[columns_cnt] = gtk_check_button_new_with_label (_(ks.column_header_txts[columns_cnt]));
         gtk_container_add (GTK_CONTAINER (columns_grid), ks.fr_in_columns[columns_cnt]);
 
         ks.fr_in_columns_css_providers[columns_cnt] = gtk_css_provider_new ();
@@ -591,7 +587,7 @@ void show_find_and_replace_dialog (void)
                                         GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
     }
 
-    ks.fr_in_all_columns = gtk_check_button_new_with_label ("All Modifiable Columns");
+    ks.fr_in_all_columns = gtk_check_button_new_with_label (_("All Modifiable Columns"));
     gtk_container_add (GTK_CONTAINER (columns_grid), ks.fr_in_all_columns);
     ks.fr_in_all_columns_css_provider = gtk_css_provider_new ();
     gtk_style_context_add_provider (gtk_widget_get_style_context (ks.fr_in_all_columns), 
